.. brave-search-python-client documentation master file, created by
   sphinx-quickstart on Thu Jan  2 09:10:01 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to brave-search-python-client's documentation!
======================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   contributing
   changelog
   reference_index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
